@@ -1,4 +1,36 @@
 
+#ifdef NCR_MP_RAS2
+typedef int ssize_t;
+#define HAVE_GETRUSAGE
+#define O_RSYNC		0
+#define SOCKLEN_T	int
+#define PATH_TMP	"/tmp"
+#define PATH_VAR_TMP	"/var/tmp"
+#define PATH_PASSWD	"/etc/passwd"
+#define PATH_WTMP	"/var/adm/wtmp"
+#define PATH_UTMP	"/var/adm/utmp"
+#define PATH_SYSLOG	"/etc/.osm"
+#define PATH_MAILLOG	"/etc/.osm"
+#define rlimit ucb_rlimit
+#include <../ucbinclude/sys/resource.h>
+#undef rlimit
+#define _SYS_RESOURCE_H
+#endif
+
+#ifdef NCR_MP_RAS3
+#define HAVE_DAEMON
+#define HAVE_GETRUSAGE
+#define O_RSYNC		0
+#define SOCKLEN_T	size_t
+#define PATH_TMP	"/tmp"
+#define PATH_VAR_TMP	"/var/tmp"
+#define PATH_PASSWD	"/etc/passwd"
+#define PATH_WTMP	"/var/adm/wtmp"
+#define PATH_UTMP	"/var/adm/utmp"
+#define PATH_SYSLOG	"/etc/.osm"
+#define PATH_MAILLOG	"/etc/.osm"
+#endif
+
 #ifdef LINUX2
 #define HAVE_DAEMON
 #define HAVE_GETRUSAGE
@@ -43,6 +75,19 @@
 #define PATH_MAILLOG	"/var/adm/syslog.dated/current/mail.log"
 #endif
 
+#ifdef OSF1
+#define HAVE_GETRUSAGE
+#define SIZEOF_IS_LONG_INT
+#define SOCKLEN_T	size_t
+#define PATH_TMP	"/tmp"
+#define PATH_VAR_TMP	"/var/tmp"
+#define PATH_PASSWD	"/etc/passwd"
+#define PATH_WTMP	"/var/adm/wtmp"
+#define PATH_UTMP	"/var/adm/utmp"
+#define PATH_SYSLOG	"/var/adm/syslog.dated/current/daemon.log"
+#define PATH_MAILLOG	"/var/adm/syslog.dated/current/mail.log"
+#endif
+
 #ifdef SOLARIS
 #define HAVE_SNPRINTF
 #define HAVE_VSNPRINTF
