@@ -73,7 +73,7 @@ static void child_handler(int received_signal /*ARGSUSED*/)
     pid = waitpid(-1, &my_gatherer_status, WNOHANG);
   } while (pid == -1 && errno == EINTR);
 
-  if (WIFEXITED(my_gatherer_status)) {
+  if (WIFEXITED(my_gatherer_status) || WIFSIGNALED(my_gatherer_status)) {
     sigchild_pid = pid;
     gatherer_status = my_gatherer_status;
   }
@@ -97,7 +97,7 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
   egd_query_t *egd_query = NULL;
   egd_query_t *egd_query_old;
   int max_fd;
-  pid_t gatherer_pid;
+  pid_t gatherer_pid, child_pid;
   int gather_fd;
   int gatherer_entry;
   int gatherer_bytes;
@@ -216,9 +216,13 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
      */
     if (caught_sigchild) {
       caught_sigchild = 0;
+      child_pid = sigchild_pid;		/* shut up warnings, as sigchild_pid */
+					/* is volatile */
       if (debug)
-	(void)fprintf(stderr, "Caught SIGCHLD\n");
-      if (sigchild_pid == gatherer_pid)
+	(void)fprintf(stderr,
+		      "Caught SIGCHLD (pid = %ld, gatherer_pid = %ld)\n",
+		      (long)child_pid, (long)gatherer_pid);
+      if (child_pid == gatherer_pid)
 	gatherer_pid = -1;
     }
 
@@ -294,13 +298,20 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
      */
     if (caught_sigchild) {
       caught_sigchild = 0;
+      child_pid = sigchild_pid;		/* shut up warnings, as sigchild_pid */
+					/* is volatile */
       if (debug)
-	(void)fprintf(stderr, "Caught SIGCHLD\n");
-      if (sigchild_pid == gatherer_pid)
+	(void)fprintf(stderr,
+		      "Caught SIGCHLD (pid = %ld, gatherer_pid = %ld)\n",
+		      (long)child_pid, (long)gatherer_pid);
+      if (child_pid == gatherer_pid)
 	gatherer_pid = -1;
     }
     if ((gatherer_pid > 0) &&
 	(difftime(time(NULL), gather_start) > seed_ext_interval / 2 + 1)) {
+      if (debug)
+	(void)fprintf(stderr, "Gathering time exceeded, kill process %ld\n",
+		      (long)gatherer_pid);
       if (kill(gatherer_pid, SIGKILL) == -1) {
       	error_error("kill() failed", errno);
       }
@@ -395,7 +406,8 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
 	gather_start = time(NULL);
 	if (debug)
 	{
-	  (void)fprintf(stderr, "Spawned gatherer: %s (%s",
+	  (void)fprintf(stderr, "Spawned gatherer (pid = %ld): %s (%s",
+		(long)gatherer_pid,
 		entropy_source[gatherer_entry].path,
 		entropy_source[gatherer_entry].args[0]);
 	  i = 1;
@@ -460,11 +472,7 @@ void main_loop(int *service_socket, int numsock, time_t seed_stat_interval,
 	else if (egd_query[i].command == 4)
 	{
 	  egd_query[i].buffer[0] = 12;
-#ifdef PID_T_IS_LONG_INT
-	  (void)sprintf((char *) (egd_query[i].buffer + 1), "%12ld", getpid());
-#else
-	  (void)sprintf((char *) (egd_query[i].buffer + 1), "%12d", (int)getpid());
-#endif
+	  (void)sprintf((char *) (egd_query[i].buffer + 1), "%12ld", (long)getpid());
 	  egd_query[i].to_process = 13;
 	  egd_query[i].yet_processed = 0;
 	  egd_query[i].state = wait_write;
